"use strict";
/*!
* Contentstack DataSync Manager
* Copyright (c) 2019 Contentstack LLC
* MIT Licensed
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildConfigPaths = void 0;
const path_1 = require("path");
/**
 * @description Builds application's config paths where data is stored
 * @returns {Object} Returns config paths
 */
const buildConfigPaths = () => {
    const baseDir = (0, path_1.resolve)((0, path_1.join)(__dirname, '..', '..', '..', '..'));
    let pluginPath;
    let tokenPath;
    if (process.env.PLUGIN_PATH) {
        if (!(0, path_1.isAbsolute)(process.env.PLUGIN_PATH)) {
            pluginPath = (0, path_1.join)(baseDir, process.env.PLUGIN_PATH);
        }
        else {
            pluginPath = process.env.PLUGIN_PATH;
        }
    }
    if (process.env.TOKEN_PATH) {
        if (!(0, path_1.isAbsolute)(process.env.TOKEN_PATH)) {
            tokenPath = (0, path_1.join)(baseDir, process.env.TOKEN_PATH);
        }
        else {
            tokenPath = process.env.TOKEN_PATH;
        }
    }
    const paths = {
        baseDir: (0, path_1.resolve)((0, path_1.join)(__dirname, '..', '..')),
        checkpoint: (0, path_1.resolve)((0, path_1.join)(tokenPath || (0, path_1.join)(baseDir, '..'), '.checkpoint')),
        failed: (0, path_1.resolve)((0, path_1.join)(tokenPath || (0, path_1.join)(baseDir, '..'), 'unprocessible', 'failed')),
        filtered: (0, path_1.resolve)((0, path_1.join)(tokenPath || (0, path_1.join)(baseDir, '..'), 'unprocessible', 'filtered')),
        ledger: (0, path_1.resolve)((0, path_1.join)(tokenPath || (0, path_1.join)(baseDir, '..'), '.ledger')),
        plugin: (0, path_1.resolve)((0, path_1.join)(pluginPath || (0, path_1.join)(baseDir, '..'), 'plugins')),
        token: (0, path_1.resolve)((0, path_1.join)(tokenPath || (0, path_1.join)(baseDir, '..'), '.token')),
        unprocessibleDir: (0, path_1.resolve)((0, path_1.join)(tokenPath || baseDir, 'unprocessible')),
    };
    return paths;
};
exports.buildConfigPaths = buildConfigPaths;
